==> hooks-0.8.10.tgz: package/lib/useTick.js <==
import { useEffect } from "react";
const tickState = { last: 0 };
export const useTick = (app, condition, interval) => {
    useEffect(() => {
        if (!app)
            return;
        if (condition !== null && typeof condition !== "string") {
            throw new Error("useTick: invalid condition");
        }
        if (typeof interval !== "number") {
            throw new Error("useTick: invalid interval");
        }
        let queryNot;
        let queryTable;
        let queryRow;
        let queryPath;
        if (condition) {
            const matches = condition.match(/^(!)?(\w+)\.(\w+).(\w+)$/);
            if (!matches) {
                throw new Error("useTick: invalid condition, must match model.field or !model.field");
            }
            queryNot = matches[1] === "!";
            queryTable = matches[2];
            queryRow = matches[3];
            queryPath = matches[4];
        }
        const tickListener = async (event) => {
            const payload = event.detail.message.payload;
            if (payload.type === "action") {
                const action = payload;
                for (const signer of app.signers) {
                    const session = await signer.getSession(app.topic, { fromCache: true });
                    if (action.address === session.address) {
                        return;
                    }
                }
                if (action.name === "tick") {
                    tickState.last = new Date().getTime();
                }
            }
        };
        app.addEventListener("message", tickListener);
        const timer = setInterval(async () => {
            // don't tick if another tick was received recently
            if (tickState.last > new Date().getTime() - interval) {
                return;
            }
            // don't tick if the condition isn't satisfied
            if (condition) {
                const result = await app.db.get(queryTable, queryRow);
                if (!result) {
                    throw new Error(`No model found at ${queryTable}.${queryRow}`);
                }
                if (queryNot ? !result[queryPath] : result[queryPath]) {
                    app.actions.tick({});
                }
            }
            else {
                app.actions.tick({}).catch((err) => console.error(err));
            }
        }, interval);
        return () => {
            clearInterval(timer);
            app.removeEventListener("message", tickListener);
        };
    }, [app, condition, interval]);
};

==> hooks-0.8.23.tgz: package/lib/useTick.js <==
import { useEffect } from "react";
const tickState = { last: 0 };
export const useTick = (app, condition, interval) => {
    useEffect(() => {
        if (!app)
            return;
        if (condition !== null && typeof condition !== "string") {
            throw new Error("useTick: invalid condition");
        }
        if (typeof interval !== "number") {
            throw new Error("useTick: invalid interval");
        }
        let queryNot;
        let queryTable;
        let queryRow;
        let queryPath;
        if (condition) {
            const matches = condition.match(/^(!)?(\w+)\.(\w+).(\w+)$/);
            if (!matches) {
                throw new Error("useTick: invalid condition, must match model.field or !model.field");
            }
            queryNot = matches[1] === "!";
            queryTable = matches[2];
            queryRow = matches[3];
            queryPath = matches[4];
        }
        const tickListener = async (event) => {
            const payload = event.detail.message.payload;
            if (payload.type === "action") {
                const action = payload;
                for (const signer of app.signers.getAll()) {
                    const session = await signer.getSession(app.topic, { fromCache: true });
                    if (action.address === session.address) {
                        return;
                    }
                }
                if (action.name === "tick") {
                    tickState.last = new Date().getTime();
                }
            }
        };
        app.addEventListener("message", tickListener);
        const timer = setInterval(async () => {
            // don't tick if another tick was received recently
            if (tickState.last > new Date().getTime() - interval) {
                return;
            }
            // don't tick if the condition isn't satisfied
            if (condition) {
                const result = await app.db.get(queryTable, queryRow);
                if (!result) {
                    throw new Error(`No model found at ${queryTable}.${queryRow}`);
                }
                if (queryNot ? !result[queryPath] : result[queryPath]) {
                    app.actions.tick({});
                }
            }
            else {
                app.actions.tick({}).catch((err) => console.error(err));
            }
        }, interval);
        return () => {
            clearInterval(timer);
            app.removeEventListener("message", tickListener);
        };
    }, [app, condition, interval]);
};
